@@ -22,6 +22,7 @@ _compositeModeMap = {
     CompositeMode.SRC_ATOP: cairo.OPERATOR_ATOP,
     CompositeMode.DEST_ATOP: cairo.OPERATOR_DEST_ATOP,
     CompositeMode.XOR: cairo.OPERATOR_XOR,
+    CompositeMode.PLUS: cairo.OPERATOR_ADD,
     CompositeMode.SCREEN: cairo.OPERATOR_SCREEN,
     CompositeMode.OVERLAY: cairo.OPERATOR_OVERLAY,
     CompositeMode.DARKEN: cairo.OPERATOR_DARKEN,
@@ -178,8 +179,6 @@ class CairoCanvas(Canvas):
         self.context.paint()
         self.context.restore()
 
-    # TODO: blendMode for PaintComposite)
-
     def _drawGradient(self, path, gradient, gradientTransform):
         self.context.new_path()
         path.replay(self._pen)
@@ -193,21 +192,61 @@ class CairoCanvas(Canvas):
 class CairoPixelSurface(Surface):
     fileExtension = ".png"
 
-    def __init__(self, boundingBox):
+    def __init__(self):
+        self._surfaces = []
+
+    @contextmanager
+    def canvas(self, boundingBox):
         x, y, xMax, yMax = boundingBox
         width = xMax - x
         height = yMax - y
-        self.surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, width, height)
-        self.context = cairo.Context(self.surface)
-        self.context.translate(-x, height + y)
-        self.context.scale(1, -1)
-        self._canvas = CairoCanvas(self.context)
+        surface = self._setupCairoSurface(width, height)
+        self._surfaces.append((surface, (width, height)))
+        context = cairo.Context(surface)
+        context.translate(-x, height + y)
+        context.scale(1, -1)
+        yield CairoCanvas(context)
 
-    @property
-    def canvas(self):
-        return self._canvas
+    def _setupCairoSurface(self, width, height):
+        return cairo.ImageSurface(cairo.FORMAT_ARGB32, width, height)
 
     def saveImage(self, path):
-        self.surface.flush()
-        self.surface.write_to_png(os.fspath(path))
-        self.surface.finish()
+        surface, _ = self._surfaces[-1]
+        surface.flush()
+        surface.write_to_png(os.fspath(path))
+        surface.finish()
+
+
+class CairoPDFSurface(CairoPixelSurface):
+    fileExtension = ".pdf"
+
+    def _setupCairoSurface(self, width, height):
+        return cairo.RecordingSurface(cairo.CONTENT_COLOR_ALPHA, (0, 0, width, height))
+
+    def saveImage(self, path):
+        _, (width, height) = self._surfaces[0]
+        pdfSurface = cairo.PDFSurface(path, width, height)
+        pdfContext = None
+        for surface, (width, height) in self._surfaces:
+            pdfSurface.set_size(width, height)
+            if pdfContext is None:
+                # It's important to call the first set_size() *before*
+                # the context is created, or we'll get an additional
+                # empty page
+                pdfContext = cairo.Context(pdfSurface)
+            pdfContext.set_source_surface(surface, 0.0, 0.0)
+            pdfContext.paint()
+            pdfContext.show_page()
+        pdfSurface.flush()
+
+
+class CairoSVGSurface(CairoPDFSurface):
+    fileExtension = ".svg"
+
+    def saveImage(self, path):
+        surface, (width, height) = self._surfaces[-1]
+        svgSurface = cairo.SVGSurface(path, width, height)
+        pdfContext = cairo.Context(svgSurface)
+        pdfContext.set_source_surface(surface, 0.0, 0.0)
+        pdfContext.paint()
+        svgSurface.flush()
